/* -*- c++ -*- */
/////////////////////////////////////////////////////////////////////////////
//
// GlErrors.cpp  -- Copyright (c) 2006 David Henry
// last modification: feb. 10, 2006
//
// This code is licenced under the MIT license.
//
// This software is provided "as is" without express or implied
// warranties. You may freely copy and compile this source into
// applications you distribute provided that the copyright text
// below is included in the resulting source code.
//
// OpenGL error management.
//
/////////////////////////////////////////////////////////////////////////////

#ifdef _WIN32
#define	WIN32_LEAN_AND_MEAN
#include <windows.h>
#endif // _WIN32

#include <GL/gl.h>
#include <GL/glext.h>
#include <iostream>

#include "GlErrors.h"

using std::cerr;
using std::endl;


// -------------------------------------------------------------------------
// checkOpenGLErrors
//
// Print the last OpenGL error code.  You can specify a message (function
// name, file, line, ...) to identify the source of the problem.
// -------------------------------------------------------------------------

GLenum
checkOpenGLErrors (const char *msg = NULL)
{
  GLenum errCode = glGetError ();

  if (errCode != GL_NO_ERROR)
    {
      cerr << msg << ": OpenGL error, ";

      switch (errCode)
	{
	case GL_INVALID_ENUM:
	  cerr << "GL_INVALID_ENUM" << endl;
	  break;

	case GL_INVALID_VALUE:
	  cerr << "GL_INVALID_VALUE" << endl;
	  break;

	case GL_INVALID_OPERATION:
	  cerr << "GL_INVALID_OPERATION" << endl;
	  break;

	case GL_STACK_OVERFLOW:
	  cerr << "GL_STACK_OVERFLOW" << endl;
	  break;

	case GL_STACK_UNDERFLOW:
	  cerr << "GL_STACK_UNDERFLOW" << endl;
	  break;

	case GL_OUT_OF_MEMORY:
	  cerr << "GL_OUT_OF_MEMORY" << endl;
	  break;

	case GL_TABLE_TOO_LARGE:
	  cerr << "GL_TABLE_TOO_LARGE" << endl;
	  break;
	}
    }

  return errCode;
}
